#******************************************************************************
#
#       Copyright:      2005-2006 Paul Obermeier (obermeier@poSoft.de)
#
#                       See the file "Tcl3D_License.txt" for information on
#                       usage and redistribution of this file, and for a
#                       DISCLAIMER OF ALL WARRANTIES.
#
#       Module:         Tcl3D -> tcl3dOgl
#       Filename:       tcl3dOglUtil.tcl
#
#       Author:         Paul Obermeier
#
#       Description:    Tcl module with miscellaneous Tcl3D OpenGL utility
#                       procedures.
#
#******************************************************************************

# Procedure to implement the OpenGL function glMultiDrawElements.

proc glMultiDrawElements { mode count type indices primcount } {
    for { set i 0 } { $i < $primcount } { incr i } {
        if { [$count get $i] > 0 } {
            glDrawElements $mode [$count get $i] $type [lindex $indices $i]
        }
    }
}

# Procedure to find out, if an OpenGL error has been occurred.
proc tcl3dOglGetError {} {
    set err [glGetError]

    if { $err == $::GL_NO_ERROR } {
        return ""
    }

    return [format "GL error: 0X%X (%s)" $err [gluErrorString $err]]
}

# Procedure to find out, if an OpenGL error has been occurred.
# OBSOLETE tcl3dCheckGlError 0.3.2 tcl3dOglGetError
proc tcl3dCheckGlError { msg } {
    set err [glGetError]

    if { $err == $::GL_NO_ERROR } {
        return 0
    }

    puts [format "%s: GL error: 0X%X (%s)" $msg $err [gluErrorString $err]]
    return 1
}
